nbxmpp.smacks

Package nbxmpp :: Module smacks |
[hide private]
[frames] | no frames]

# Module smacks

source code

Classes | [hide private]
| Smacks This is Smacks is the Stream Management class. It takes care of requesting and sending acks. Also, it keeps track of the unhandled outgoing stanzas.

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.smacks')`
| __package__ = ``'``nbxmpp``'``

Imports: Acks, NS_STREAM_MGMT, logging

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.smacks')

  ### __package__ Value:
      'nbxmpp'